# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

# (akien) No soname upstream, arbitrarily using 0 for now
# Without proper soname, the devel package would not generate the
# devel() provides that RPM relies on to pull in the proper deps
# in reverse dependencies.
%define major   11
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

# Comment out when using stable release.
# Upstream tracks git commits in their known_good.json, so we are forced to do the same.
# See vulkan-validation-layers for the required known_good commit for this package.
%define git dd69df7f3dac26362e10b0f38efb9e47990f7537
%define shortgit %(echo %{git} | cut -c1-7)
%define rel 1

# Cyclic dependencies between HLSL and glslang, we can't build with --no-undefined
# for the time being: https://github.com/KhronosGroup/glslang/issues/1484
%define _disable_ld_no_undefined 1

Name:           glslang
# Check CHANGES.md
Version:        11.0.0
Release:        %mkrel %{rel}%{?git:.%{shortgit}}
Summary:        Khronos reference front-end for GLSL and ESSL, and sample SPIR-V generator
Group:          System/Libraries
License:        BSD and GPLv3+ and ASL 2.0
URL:            https://github.com/KhronosGroup
%if 0%{?git:1}
Source0:        https://github.com/KhronosGroup/glslang/archive/%{shortgit}/%{name}-%{shortgit}.tar.gz
%else
Source0:        https://github.com/KhronosGroup/glslang/archive/%{version}/%{name}-%{version}.tar.gz
%endif
# https://github.com/KhronosGroup/glslang/pull/1621
Patch1:         0001-CMake-Allow-linking-against-system-installed-SPIRV-T.patch
# https://github.com/KhronosGroup/glslang/pull/2419
Patch2:         0001-CMake-Make-glslang-default-resource-limits-STATIC.patch
Patch3:         0002-CMake-Use-VERSION-SOVERSION-for-all-shared-libs.patch
# https://github.com/KhronosGroup/glslang/pull/1978
Patch4:         0001-glslang-Rename-and-move-cmake-export.patch
Patch5:         0002-cmake-Use-the-same-export-config-for-all-installed-t.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(SPIRV-Tools) >= 2020.5
BuildRequires:  python3

%description
%{name} is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

%package -n %{libname}
Summary:        Library files for glslang
Group:          System/Libraries
# Renamed during mga7 development
Obsoletes:      %{_lib}glslang < 7.10.2984-2

%description -n %{libname}
Library files for glslang.

%package -n %{devname}
Summary:        Development files for glslang
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
%{name} is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

%prep
%autosetup -p1 %{?git:-n %{name}-%{git}}

%build
%cmake
%cmake_build

%install
%cmake_install

# Not needed, linked into the shared libs
rm -f %{buildroot}%{_libdir}/*.a

%check
pushd Test
LD_LIBRARY_PATH+=%{buildroot}%{_libdir} ./runtests localResults \
  %{buildroot}%{_bindir}/glslangValidator \
  %{buildroot}%{_bindir}/spirv-remap
popd

%files
%doc README.md README-spirv-remap.txt
%{_bindir}/glslangValidator
%{_bindir}/spirv-remap

%files -n %{libname}
%{_libdir}/lib%{name}*.so.%{major}
%{_libdir}/lib%{name}*.so.%{version}
%{_libdir}/libHLSL.so.%{major}
%{_libdir}/libHLSL.so.%{version}
%{_libdir}/libSPIRV.so.%{major}
%{_libdir}/libSPIRV.so.%{version}
%{_libdir}/libSPVRemapper.so.%{major}
%{_libdir}/libSPVRemapper.so.%{version}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/
%{_libdir}/lib%{name}*.so
%{_libdir}/libHLSL.so
%{_libdir}/libSPIRV.so
%{_libdir}/libSPVRemapper.so


%changelog
* Wed Dec 30 2020 akien <akien> 11.0.0-1.dd69df7.mga8
+ Revision: 1666495
- Commit dd69df7, matching requirements for Vulkan SDK 1.2.162.0

* Mon Oct 12 2020 akien <akien> 11.0.0-1.bacaef3.mga8
+ Revision: 1633970
- Version 11.0.0 (needed for Vulkan SDK 1.2.154.0)
- Rebase patches and submit them upstream

* Mon Feb 17 2020 akien <akien> 8.13.3559-1.4fc7a33.mga8
+ Revision: 1536928
- Commit 4fc7a33, necessary for Vulkan SDK 1.2.131.2

* Sun Feb 16 2020 umeabot <umeabot> 7.12.3381-2.3495381.mga8
+ Revision: 1533962
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Sep 25 2019 akien <akien> 7.12.3381-1.3495381.mga8
+ Revision: 1445857
- Commit 3495381, necessary for Vulkan SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 7.11.3113-4.e06c7e9.mga7
+ Revision: 1393159
- Commit e06c7e9, matching requirements from Vulkan SDK 1.1.106.0

* Wed Mar 27 2019 akien <akien> 7.11.3113-3.5432f0d.mga7
+ Revision: 1380636
- Rebuild against updated spirv-headers and spirv-tools, needed to be able to build vulkan-validation-layers 1.1.101.0

* Wed Mar 27 2019 akien <akien> 7.11.3113-2.5432f0d.mga7
+ Revision: 1380629
- Update to git commit 5432f0d, known_good version for Vulkan SDK 1.1.101.0

* Tue Mar 26 2019 akien <akien> 7.11.3113-1.mga7
+ Revision: 1380460
- Version 7.11.3113

* Tue Dec 11 2018 akien <akien> 7.10.2984-3.mga7
+ Revision: 1340227
- Rebuild to pick updated spirv-tools on armv7hl

* Tue Dec 11 2018 akien <akien> 7.10.2984-2.mga7
+ Revision: 1340206
- Properly libify with defined soname (major 0 for now)

* Mon Dec 10 2018 akien <akien> 7.10.2984-1.mga7
+ Revision: 1339877
- Adapt to Mageia's library policy
- Build as shared libraries
- Build against system SPIRV-Tools for HLSL support
- Fix underlinking of OSDependent (other underlinking issues remain in HLSL)
- import glslang from Fedora Rawhide

